@@ -121,6 +121,7 @@ __all__ = (
     "ScheduleConfigurationTypeDef",
     "ScheduleEntryTypeDef",
     "SecretsManagerAccessTokenConfigurationTypeDef",
+    "SegmentDeliveryConfigurationTypeDef",
     "SlateSourceTypeDef",
     "SourceLocationTypeDef",
     "SpliceInsertMessageTypeDef",
@@ -385,6 +386,7 @@ _OptionalCreateSourceLocationRequestRequestTypeDef = TypedDict(
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
+        "SegmentDeliveryConfigurations": Sequence["SegmentDeliveryConfigurationTypeDef"],
         "Tags": Mapping[str, str],
     },
     total=False,
@@ -407,6 +409,7 @@ CreateSourceLocationResponseTypeDef = TypedDict(
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "LastModifiedTime": datetime,
+        "SegmentDeliveryConfigurations": List["SegmentDeliveryConfigurationTypeDef"],
         "SourceLocationName": str,
         "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -602,6 +605,7 @@ DescribeSourceLocationResponseTypeDef = TypedDict(
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "LastModifiedTime": datetime,
+        "SegmentDeliveryConfigurations": List["SegmentDeliveryConfigurationTypeDef"],
         "SourceLocationName": str,
         "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1222,6 +1226,15 @@ SecretsManagerAccessTokenConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+SegmentDeliveryConfigurationTypeDef = TypedDict(
+    "SegmentDeliveryConfigurationTypeDef",
+    {
+        "BaseUrl": str,
+        "Name": str,
+    },
+    total=False,
+)
+
 SlateSourceTypeDef = TypedDict(
     "SlateSourceTypeDef",
     {
@@ -1246,6 +1259,7 @@ _OptionalSourceLocationTypeDef = TypedDict(
         "CreationTime": datetime,
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
         "LastModifiedTime": datetime,
+        "SegmentDeliveryConfigurations": List["SegmentDeliveryConfigurationTypeDef"],
         "Tags": Dict[str, str],
     },
     total=False,
@@ -1368,6 +1382,7 @@ _OptionalUpdateSourceLocationRequestRequestTypeDef = TypedDict(
     {
         "AccessConfiguration": "AccessConfigurationTypeDef",
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
+        "SegmentDeliveryConfigurations": Sequence["SegmentDeliveryConfigurationTypeDef"],
     },
     total=False,
 )
@@ -1389,6 +1404,7 @@ UpdateSourceLocationResponseTypeDef = TypedDict(
         "DefaultSegmentDeliveryConfiguration": "DefaultSegmentDeliveryConfigurationTypeDef",
         "HttpConfiguration": "HttpConfigurationTypeDef",
         "LastModifiedTime": datetime,
+        "SegmentDeliveryConfigurations": List["SegmentDeliveryConfigurationTypeDef"],
         "SourceLocationName": str,
         "Tags": Dict[str, str],
         "ResponseMetadata": "ResponseMetadataTypeDef",
